==> kraken-0.9.11.tar.gz: kraken-0.9.11/kraken/lib/log.py <==
# -*- coding: utf-8 -*-
#
# Copyright 2018 Benjamin Kiessling
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
# or implied. See the License for the specific language governing
# permissions and limitations under the License.
"""
kraken.lib.log
~~~~~~~~~~~~~~~~~

Handlers and formatters for logging.
"""

import time
import click
import logging

class LogHandler(logging.Handler):
    def emit(self, record):
        msg = self.format(record)
        level = record.levelname.lower()
        err = level in ('warning', 'error', 'exception', 'critical')
        click.echo(msg, err=err)

class LogFormatter(logging.Formatter):
    colors = {
        'error': dict(fg='red'),
        'exception': dict(fg='red'),
        'critical': dict(fg='red'),
        'warning': dict(fg='yellow'),
    }

    st_time = time.time()

    def format(self, record):
        if not record.exc_info:
            level = record.levelname.lower()
            msg = record.msg
            if level in self.colors:
                style = self.colors[leve]
            else:
                style = {}
            msg = click.style(u'[{:2.4f}] {} '.format(time.time() - self.st_time, msg), **style)
            return msg
        return logging.Formatter.format(self, record)

def set_logger(logger=None, level=logging.ERROR):
    handler = LogHandler()
    handler.setFormatter(LogFormatter())
    logger.addHandler(handler)
    logger.setLevel(level)

==> kraken-0.9.15.tar.gz: kraken-0.9.15/kraken/lib/log.py <==
# -*- coding: utf-8 -*-
#
# Copyright 2018 Benjamin Kiessling
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
# or implied. See the License for the specific language governing
# permissions and limitations under the License.
"""
kraken.lib.log
~~~~~~~~~~~~~~~~~

Handlers and formatters for logging.
"""

import time
import click
import logging

class LogHandler(logging.Handler):
    def emit(self, record):
        msg = self.format(record)
        level = record.levelname.lower()
        err = level in ('warning', 'error', 'exception', 'critical')
        click.echo(msg, err=err)

class LogFormatter(logging.Formatter):
    colors = {
        'error': dict(fg='red'),
        'exception': dict(fg='red'),
        'critical': dict(fg='red'),
        'warning': dict(fg='yellow'),
    }

    st_time = time.time()

    def format(self, record):
        if not record.exc_info:
            level = record.levelname.lower()
            msg = record.msg
            if level in self.colors:
                style = self.colors[level]
            else:
                style = {}
            msg = click.style(u'[{:2.4f}] {} '.format(time.time() - self.st_time, msg), **style)
            return msg
        return logging.Formatter.format(self, record)

def set_logger(logger=None, level=logging.ERROR):
    handler = LogHandler()
    handler.setFormatter(LogFormatter())
    logger.addHandler(handler)
    logger.setLevel(level)
